# JSON-Editor-PySide6
Visual JSON Editor written in Qt

# NOTE

Adapted to pyside6 from [JSON-Editor](https://github.com/rBrenick/json-editor).

Check out his version! 
This version is meant mainly to be used inside compare-my-stocks. 
